@@ -17,9 +17,8 @@ def tipo_colonna(df, colonna):
 def leggi_csv(file_name):
     import time
     start = time.time()
-    df = pd.read_csv(file_name)
+    df = pd.read_csv(file_name,delimiter=',' ,encoding='utf-8')
     end = time.time()
-    df = df.reindex(lista_colonne(df), axis=1)
     print("Tempo impiegato per leggere il file: ", end-start)
     return df
 
